import { ShContextService } from './sh-context-service';
import { Directive, Input, HostListener, ViewContainerRef, ComponentFactoryResolver } from "@angular/core";
import { ShContextOverlayComponent } from './sh-context-overlay.component';
import { ShContextMenuComponent } from "./sh-context-menu.component";
var ShContextMenuDirective = (function () {
    function ShContextMenuDirective(viewRef, resolver, ctxService) {
        this.viewRef = viewRef;
        this.resolver = resolver;
        this.ctxService = ctxService;
    }
    ShContextMenuDirective.prototype.onClick = function (event) {
        this.options = this.ctxService.setOptions(this.options);
        this.closeMenu();
        this.ctxComponent = this.createContextComponent();
        this.overlayComponent = this.createOverlayComponent();
        this.registerBindings();
        this.registerEvents();
        this.setLocation(event);
        return false;
    };
    ShContextMenuDirective.prototype.registerEvents = function () {
        var _this = this;
        this.ctxComponent.instance.onClose.subscribe(function () {
            _this.closeMenu();
        });
        this.overlayComponent.instance.onClick.subscribe(function () { _this.closeMenu(); });
    };
    ShContextMenuDirective.prototype.registerBindings = function () {
        this.ctxComponent.instance.items = this.menuItems;
        this.ctxComponent.instance.dataContext = this.dataContext;
    };
    ShContextMenuDirective.prototype.createContextComponent = function () {
        var shContextMenuFactory = this.resolver.resolveComponentFactory(ShContextMenuComponent);
        var shContextComponentRef = this.viewRef.createComponent(shContextMenuFactory);
        return shContextComponentRef;
    };
    ShContextMenuDirective.prototype.createOverlayComponent = function () {
        var shContextOverlayFactory = this.resolver.resolveComponentFactory(ShContextOverlayComponent);
        var shContextOverlayRef = this.viewRef.createComponent(shContextOverlayFactory);
        return shContextOverlayRef;
    };
    ShContextMenuDirective.prototype.setLocation = function (event) {
        var clientX = event.clientX, clientY = event.clientY;
        var position = {
            top: clientY,
            left: clientX
        };
        this.ctxComponent.instance.position = position;
    };
    ShContextMenuDirective.prototype.closeMenu = function () {
        this.viewRef.clear();
    };
    return ShContextMenuDirective;
}());
export { ShContextMenuDirective };
ShContextMenuDirective.decorators = [
    { type: Directive, args: [{
                selector: '[sh-context]'
            },] },
];
/** @nocollapse */
ShContextMenuDirective.ctorParameters = function () { return [
    { type: ViewContainerRef, },
    { type: ComponentFactoryResolver, },
    { type: ShContextService, },
]; };
ShContextMenuDirective.propDecorators = {
    'menuItems': [{ type: Input, args: ['sh-context',] },],
    'dataContext': [{ type: Input, args: ['sh-data-context',] },],
    'options': [{ type: Input, args: ['sh-options',] },],
    'onClick': [{ type: HostListener, args: ['contextmenu', ['$event'],] },],
};
//# sourceMappingURL=sh-context-menu.directive.js.map